@@ -352,7 +352,7 @@ class nlmsg_base(dict):
                         if field[1] == 'z' and self[name][-1] in (0x00, '\0'):
                             self[name] = self[name][:-1]
                     else:
-                        self.update(dict(zip(name.split(","), value)))
+                        self[name] = value
 
                 else:
                     # FIXME: log an error
@@ -404,7 +404,10 @@ class nlmsg_base(dict):
                         value = int(value)
 
                 try:
-                    payload += struct.pack(fmt, value)
+                    if type(value) in (list, tuple, set):
+                        payload += struct.pack(fmt, *value)
+                    else:
+                        payload += struct.pack(fmt, value)
                 except struct.error:
                     logging.error(traceback.format_exc())
                     logging.error("error pack: %s %s %s" %
